**Example 1: 删除ES集群实例**

删除指定ID的集群实例

Input: 

```
tccli es DeleteInstance --cli-unfold-argument  \
    --InstanceId es-xxxxxxxx
```

Output: 
```
{
    "Response": {
        "RequestId": "6eb5c3b2-0bba-4f73-bafb-bd21esxxxxxx"
    }
}
```

